@@ -2144,7 +2144,7 @@ int lttng_ustconsumer_data_pending(struct lttng_consumer_stream *stream)
 		 */
 		DBG("UST consumer metadata pending check: contiguous %" PRIu64 " vs pushed %" PRIu64,
 				contiguous, pushed);
-		assert(((int64_t) contiguous - pushed) >= 0);
+		assert(((int64_t) (contiguous - pushed)) >= 0);
 		if ((contiguous != pushed) ||
 				(((int64_t) contiguous - pushed) > 0 || contiguous == 0)) {
 			ret = 1;	/* Data is pending */
